# version 2.1.0
----------------
 * fix codes ignored in raw strings #432
 * update zoomeye api to v2

# verison 2.0.8
 * Fix nucleic dsl syntax parsing #386 @xixixiba
 * Fix the compatibility issue of -l command in windows #400 @geelph

# version 2.0.7
 * add http debug level command line parameter --http-debug
 * fix some bug

# version 2.0.6
* add new command -l show local poc
* build the corresponding vulnerability environment based on the PoC, For details, please refer to pocs/Apache_Struct2

# version 2.0.5
----------------
* fix hook failure due to urllib3 update #368 #373
* optimize DSL expression execution #372
* making mmh3 an optional dependency #359
* disable mandatory updates

# version 2.0.4
----------------
* Updated protocol names that are compatible with Nuclei v2.9.1

# version 2.0.3
----------------
* optimized URL protocol correction #356, thanks @chenjiewei123
* support disable protocol correction and honeypot checks through --no-check option

# version 2.0.2
----------------
* fix url redirect problem in _check method #337
* fix use command in console mode can't use absolute path #341, thanks @S2eTo
* fix ipv6 compatibility issue in build_url #347, thanks @HomerQing
* optimize dsl expression execution #348

# version 2.0.1
----------------
* fix words matcher expression execution #333, thanks @soapffz
* fix catch binascii ValueError Exception #334, thanks @izj007
* improve template robustness
* support digest_username and digest_password
* support negative matchers

# version 2.0.0
----------------
* yaml poc support, compatible with nuclei
* fix httpserver module hangs on macos platform
* auto correction of url protocol based on status code

# version 1.9.11
----------------
* support customize poc protocol and default port #321
* -p option support optional protocol field, [proto:]port #323
* add -s option to skip target default port #323
* poc-console optimization
* some bug fixes & improvements

# version 1.9.10
----------------
fix different python versions have different behaviors on ipaddress library #319

# version 1.9.9
----------------
* auto correct url based on poc's protocol attribute #316
* fix Colorizing doesn't work on Windows with poc-console #318
* trail slash at the end of url #314

# version 1.9.8
----------------
* support full PoC search by regex keyword #312
* set default value for PoC in POCBase #312
* add bind/reverse shell payload #311
* fix fofa query over multiple pages #310

# version 1.9.7
----------------
* improve encoding compatibility #305
* obfuscate REVERSE_PAYLOAD to evade windows defender #306
* improve --ppt

# version 1.9.6
----------------
* support -o parameter, save the result in json lines format
* optimize timeout for cyberspace search engine plugins
* optimize the handling of the url protocol
* docs update

# version 1.9.5
----------------
* refactor --ppt, optimize mosaic for url
* optimize poc template
* optimize pocsuite command default prompt message
* adjust the default timeout to 10 seconds
* adjust the default number of threads to 150
* target url support cidr, user can use -p provide additional ports
* support local mode, local mode do not need any targets, e.g. LPE
* bug fixes

# version 1.9.4
-----------------
* support poc template generate
* support custom interactsh server
* Switch the authentication method of ZoomEye and CEYE to API-KEY
* support honeypot detect
* support http/https protocol autocorrect
* refactor --update
* support version check

# version 1.9.3
-----------------
* add support for qianxin hunter cyberspace search engine
* support self.rhost & self.rport in POCBase

# version 1.9.2
-----------------
* Improved shell mode

# version 1.9.1
-----------------
* fix #272, #274
* the hook support of requests can be used alone
* refactor shell mode, add handle for keyboard interrupt

# version 1.9.0
-----------------
* Fix urllib3 issue with parsing URIs
* Prevent URL encoding

# version 1.8.12
-----------------
* update fofa api url #263

# version 1.8.11
-----------------
* fix windows log color issue #258

# version 1.8.10
-----------------
* fix #254
* fix urlparse fails with simple url
* use pycryptodomex instead of pycryptodome, fix #255

# version 1.8.9
-----------------
* fix user-agent bug #252

# version 1.8.8
-----------------
* rewrite multi module
* integrate with interactsh
* support filter poc by keyword

# version 1.8.7
-----------------
* fix bug
* optimize code style & docs
* delete the exe tool for compatibility with dfsg

# version 1.8.6
-----------------
* support encrypted shell (TLS) in shell mode
* fix #228

# version 1.8.5
-----------------
* support bind shell in shell mode
* fix #221

# version 1.8.4
-----------------
* update docs
* fix typo

# version 1.8.3
-----------------
* some improvements related to dependent

# version 1.8.2
-----------------
* fix finding a python module version gives error

# version 1.8.1
-----------------
* fix check_requires() can not handle dependent version correctly #208
* update docs

# version 1.8.0
-----------------
* fix the timeout problem in shell mode leads to confusing results
* made some improvements with network address related issues

# version 1.7.8
-----------------
* add option to display extra parameters of poc
* add more poc attribute to result dict
* allow custom module path in console mode
* fix some compatibility problems

# version 1.7.7
-----------------
* 添加--dork自动用poc中的dork字段扫描功能
* 适配Debian源格式需求

# version 1.7.6
-----------------
* fixes #192

# version 1.7.5
-----------------
* 添加录包功能和dork字段支持base64编码 fixes #169 #173
* 修复target插件requests参数无效bug fix #183

# version 1.7.4
-----------------
* 修复批量执行poc时因为报错导致扫描中断问题 fixes #149
* 修复--pocs-path参数bug

# version 1.7.2
-----------------
* 增加powershell bash反弹shell 以及编码函数

# version 1.7.0
-----------------
* 修复`Python 3.9`兼容性问题
* console模式，添加系统命令执行，添加pocuite3命令clear清除屏幕

# version 1.6.5
----------------
* 修复http请求头不能删除
* 修复html导出编码错误
* 修复console模式下lport设置失败
* shell模式可以使用select或use选择shell

# version 1.6.4
----------------
* 测试Github Action自动发布pypi

# version 1.6.0~1.6.3
---------------
* 添加随机UA头选项
* 重构--ppt隐藏信息选项
* 当poc有语法错误时，显示详细信息
* 添加InMemoryWar
* 修复urllib3的`chunk_length`错误
* 加入打tag自动构建发布到pypi

# version 1.5.9
---------------
* 增加了poc类型的枚举类型 #95
* 修改了样例poc

# version 1.5.8
---------------
* 修复shadon api问题
* 加入fofa api接口

# version 1.5.7
---------------
* 取消pyreadline报错提示
* 修改日志拼写错误

# version 1.5.6
---------------
* 修复多线程卡住问题
* 修复seebug api问题
* 修复socks5代理问题

# version 1.5.5
---------------
* fix #87

# version 1.5.4
---------------
* 加入获取PoC信息的API
* 更新测试用例

# version 1.5.3
---------------
* socket代理增加变量保存原始socket信息，方便使用后恢复(`conf.origin_socks`)
* 修复requests代理指定为None时的逻辑问题

# version 1.5.2
---------------
* typo fix #84
* bugfix 自定义cookie产生的异常情况
* bugfix 引入pocsuite3后再次引入requests导致的报错

# version 1.5.1
---------------
* 修复插件调用poc失败的问题

# version 1.5.0
---------------
* 修复timeout一处异常
* pocsuite3.api 添加 `random_str`
* 优化update function

# version 1.4.9
---------------
* 修复requirement检测一处bug
* 修复reverse 一处异常

# version 1.4.8
---------------
* console模式下设置ip可以选择序号 `show ip` `set lhost 0`
* bugfix for ceye dns api

# version 1.4.7
---------------
* 修复console模式下回连shell循环的异常

# version 1.4.6
---------------
* 修复`-v`出现的问题
* 修复加载多个poc可能出现的问题

# version 1.4.5
---------------
* update usage.md

# version 1.4.3
---------------
* 加入PPT模式（用于演示，敏感信息将打上*）

# version 1.4.2
---------------
* 修复console模式下一处bug，https://github.com/knownsec/pocsuite3/pull/61

# version 1.4.1
---------------
* 修复由poc插件中由conf.poc引起的错误

# version 1.4.0
---------------
* 在命令行下url和poc支持多个(空格分隔)
* 更换`optparse`到`argparse`

# version 1.3.9
---------------
* 修复plugins选项加载绝对路径问题
* 修复加载pocs目录扫描部分报错问题
* PoC插件`add_poc`方法新增`fullname`参数用于定义加载poc名称
* 定义api模式方便shell集成

# version 1.3.8
---------------
* add field,option for compatibility with zipoc

# version 1.3.7
---------------
* add poc-plugin to load poc from `pocs` directories.

# version 1.3.6
---------------
* Bugfix parameter `version`

# version 1.3.5
---------------
* Add parameter `-c` for load configuration from the configuration file
* Add parameter `--comparsion` for comparing comparing both of zoomeye and shodan
* Interface supports from zoomeye,shodan and censys

# version 1.3.4
---------------
Cross-platform shell code generation

# version 1.3.3
---------------
fix #37 pocsuite3\lib\core\revision.py

# version 1.3.2
---------------
* bugfix poc thinkphp_rce

# version 1.3.1
---------------
* add confluence poc
* fix pocs/drupalgeddon2
* CYGWIN compatibility
* bugfix revision.py `stdout_encode`

# version 1.3.0
---------------
* new feature: `_verify` `_attack` function can directly return bool, str, dict, etc.
* new plugin: file report
* bugfix get_option() not support int

# version 1.2.10
---------------
* bugfix interpreter_option OptDict

# version 1.2.9
---------------
* seebug poc friendly load reminder
* new feature:displayed results after user interruption
* POC specifies third-party module verification failure
* customize option iter func
* Built-in http server

# version 1.2.8
---------------
* support ceye token
* bugfix plugin from seebug
* refactoring ceye

# version 1.2.7
---------------
* bugfix hook_requests

# version 1.2.6
---------------
* bugfix seebug poc

# version 1.2.5
---------------
* bugfix socks proxy

# version 1.2.2
---------------
* bugfix site-packages poc-console issue
* poc-console support to load absolute path
* poc-console will ignore case when use `search`

# version 1.2.1
---------------
* bugfix auto update error
* bugfix console mode load poc error
* update pocsuite3 banner

# version 1.0
---------------
* Init publish
